import { JSDOM } from "jsdom";

export default {
  convertRelativeLinks: (htmlContent, domain) => {
    if (!htmlContent || !domain) return htmlContent;

    const dom = new JSDOM(htmlContent);
    const document = dom.window.document;

    document.querySelectorAll("a[href]").forEach(link => {
      let href = link.getAttribute("href");

      if (href.startsWith("#")) {
        const span = document.createElement("span");
        span.textContent = link.textContent;
        link.replaceWith(span);
        return;
      }

      if (!href.startsWith("http://") && !href.startsWith("https://"))
        link.setAttribute("href", `${domain.replace(/\/$/, '')}/${href.replace(/^\/+/, '')}`);
    });

    return document.body.innerHTML;
  },
  generatePermalink: (url, baseUrl) => {
    if (url?.includes("http") || !baseUrl) return url
    return `${baseUrl}${url}`
  },
  getRemoteFileSize: async (url) => {
    try {
      const response = await fetch(url, { method: "HEAD" });
      if (!response.ok) return 0;
      const contentLength = response.headers.get("content-length");
      if (!contentLength) return 0;
      return parseInt(contentLength, 10);
    } catch (error) {
      return 0;
    }
  }
}
